/*
 * Copyright © 2006 Carl Worth
 *
 * This program is free software; you can redistribute it and\/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA."
 */
#include <stdlib.h>
#include <goocanvas.h>
#include "demo-item.h"

static gboolean
on_delete_event (GtkWidget *window,
		 GdkEvent  *event,
		 gpointer   unused_data)
{
    exit (0);
}

static GtkWidget *
create_window (void)
{
    GtkWidget *window, *scrolled_window;

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_window_set_default_size (GTK_WINDOW (window), 500, 500);
    gtk_widget_show (window);
    g_signal_connect (window, "delete_event",
		      (GtkSignalFunc) on_delete_event, NULL);

    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
					 GTK_SHADOW_IN);
    gtk_scrolled_window_set_policy  (GTK_SCROLLED_WINDOW (scrolled_window),
				     GTK_POLICY_AUTOMATIC,
				     GTK_POLICY_AUTOMATIC);
    gtk_widget_show (scrolled_window);
    gtk_container_add (GTK_CONTAINER (window), scrolled_window);

    return scrolled_window;
}

static gboolean
on_button_press (GooCanvasItem  *item,
		 GooCanvasItem  *target,
		 GdkEventButton *event,
		 gpointer        data)
{
    g_print ("demo item received button press event\n");
    return TRUE;
}

static void
create_canvas (GtkWidget *parent)
{
    GtkWidget *canvas;
    GooCanvasItem *root, *rect;

    canvas = goo_canvas_new ();
    gtk_widget_set_size_request (canvas, 400, 400);
    goo_canvas_set_bounds (GOO_CANVAS (canvas), 0, 0, 400, 400);
    gtk_widget_show (canvas);
    gtk_container_add (GTK_CONTAINER (parent), canvas);

    root = goo_canvas_get_root_item (GOO_CANVAS (canvas));

    rect = goo_demo_item_new (root, 30, 20, 50, 30,
			      "fill-color", "purple",
			      NULL);

    g_signal_connect (rect, "button_press_event",
		      (GtkSignalFunc) on_button_press, NULL);

}

int
main (int argc, char *argv[])
{
    GtkWidget *window;

    gtk_init (&argc, &argv);

    window = create_window ();

    create_canvas (window);

    gtk_main ();

    return 0;
}
